/*
Copyright (c) 1998-2009 VIA Technologies, Inc. All Rights Reserved.
 
This PROPRIETARY SOURCE CODE contains proprietary information of VIA 
Technologies, Inc. (VIA); Contents of this file shall not be disclosed to any 3rd party, 
copied or duplicated in any form, in whole or in part without prior written consent of 
VIA.  THIS SOURCE CODE & ANY RELATED DOCUMENTATION 
(COLLECTIVELY SOFTWARE) ARE PROVIDED AS IS, WITH ALL FAULTS, & 
WITHOUT WARRANTY OF ANY KIND.  VIA DISCLAIMS ALL EXPRESS OR 
IMPLIED WARRANTIES.  USER ACKNOWLEDGES THAT PARTIES FOR ANY 
DAMAGES ARISING FROM USE OF SOFTWARE OR ITS DERIVATIVE, 
INCLUDING, W/O LIMITATION, LOSS OF USE, DATA OR PROFITS. USER
WHOLLY ASSUMES ALL RISK ARISING FROM USE & PERFORMANCE OF 
SOFTWARE
*/ 
 
#ifndef FDAPI_BASE_H_
#define FDAPI_BASE_H_

#ifdef linux
// base type
#ifndef FD_ALL_BASE_TYPE
#define FD_ALL_BASE_TYPE
typedef unsigned char	BYTE;
typedef unsigned short	WORD;
typedef unsigned long	DWORD;
typedef long long __int64;

typedef BYTE		UCHAR;
typedef WORD		USHORT;
typedef DWORD		ULONG;

typedef UCHAR 		*PUCHAR;
typedef USHORT 		*PUSHORT;
typedef ULONG 		*PULONG;
typedef void		*PVOID;

typedef char			TCHAR;

// both SDK & driver
#ifndef HANDLE
#define HANDLE PVOID
#endif

#endif // #ifndef FD_ALL_BASE_TYPE

#ifndef BOOL
#define BOOL DWORD
#endif

#ifndef FALSE
#define FALSE (0)
#endif

// same as windows
#ifndef TRUE
#define TRUE (1)
#endif

#endif // linux

#ifdef __cplusplus
extern "C" {
#endif

#ifdef linux
#define FLITEDECK_API

#else

#include <windows.h>

#ifdef FLITEDECK_EXPORTS
#define FLITEDECK_API __declspec(dllexport)
#else
#define FLITEDECK_API __declspec(dllimport)
#endif

#endif

/************************************************************************
							Error Code
************************************************************************/
/**
 * @def FD_S_OK
 * @brief  The function is success.
 */
#define FD_S_OK						0
/**
 * @def FD_S_EXTSMI_NOT_START
 * @brief  The external SMI function does not be started.
 */
#define FD_S_EXTSMI_NOT_START		1000

/**
 * @def FD_E_FAIL
 * @brief  The function fails.
 */
#define FD_E_FAIL					-1000
/**
 * @def FD_E_BOARD_NOT_SUPPORT
 * @brief  The board is not supported.
 */
#define FD_E_BOARD_NOT_SUPPORT		-1001
/**
 * @def FD_E_ALREADY_INITIALIZED
 * @brief  FliteDeck dll has been loaded.
 */
#define FD_E_ALREADY_INITIALIZED	-1002

/**
 * @def FD_E_INVALID_ARG
 * @brief  The arguments are invalid.
 */
#define FD_E_INVALID_ARG			-1003

/**
 * @def FD_E_OUT_OF_MEMORY
 * @brief  Out of memory.
 */
#define FD_E_OUT_OF_MEMORY			-1004

/**
 * @def FD_E_FUNC_NOT_SUPPORT
 * @brief  The function is not supported on this board.
 */
#define FD_E_FUNC_NOT_SUPPORT		-1005

/**
 * @def FD_E_HARDWARE_ERROR
 * @brief  Hardware error.
 */
#define FD_E_HARDWARE_ERROR			-1006

/**
 * @def FD_E_HARDWARE_ERROR
 * @brief  Hardware error.
 */
#define FD_E_HARDWARE_BUSY			-1007

/**
 * initial the FliteDeck SDK, and the SDK loads the driver.
 * @param pszBoardName: a pointer to the detected board name.
 * @return   :
 * FD_S_OK: The function is success.
 * FD_E_ALREADY_INITIALIZED: Other application was already initialized.
 * FD_E_BOARD_NOT_SUPPORT: The board is not supported.
 * FD_E_FAIL: The function fails.
 * @see FD_UnInitialize()
 */
FLITEDECK_API DWORD FD_Initialize(TCHAR * pszBoardName);

/**
 * release the FliteDeck SDK, and the SDK unloads the driver.
 * @return   : Returns TRUE if successful or FALSE otherwise.
 * @remarks  : You MUST BE SURE that FD_UnInitialize() is called when the application is closed.
 *             Otherwise FD_Initialize() cannot be normally called next time.
 */
FLITEDECK_API BOOL FD_UnInitialize(void);


#ifdef __cplusplus
} // extern C
#endif

#endif // FDAPI_BASE_H_
